c=======================================================================
c
c     URRDIFF = Same as URRDO, except replace CUREENT by OTHER =
c               TOTAL - (ELASTIC + CAPTURE + FISSION).
c
c     URRDO (2015-1) *Process Unresolved Resonance Region (URR), Do URR
c           (2016-1) *For 2 bands conserve 1/[sigmaT + sigma0], where
c                     sigma0 = the unshielded average total.
c
c     WARNING - This only does the first MAT on the ENDF input file
c     =============================================================
c
c     List NJOY PTM parameters from MF/MT=2/152 and 2/153
c
c     Output back into the ENDF format - after testing we
c     can use this to change parameters anyway we want,
c     0) Original data
c     1) Turn off self-shielding
c     2) Explace PTM by MB parameters
c
c     The output listing (in URRDIFF.LST) will always list the
c     ORIGINAL data as read - the ouput option only controls what
c     is written to the ENDF output file. To obtain a listing of
c     the NEW data in the ENDF output file, run this code a second
c     time using the created ENDF OUTPUT as the ENDF INPUT.
c
c     I/O File Definitions
c     ====================
c        2 = URRDIFF.INP
c        3 = URRDIFF.LST
c       10 = Input  ENDF data (variable input - see below)
c       11 = Output ENDF data (variable input - see below)
c       16 = VS-ENERGY.CUR = F1 and F2 versus Energy.
c       17 = VS-SIGMA0.CUR = F1 vs. Sigma0 first and last energies
c
c     Input Parameters(in URRDIFF.INP)
c     ================================
c     Line  Columns Definition
c     ========================
c        1  1-72    Input ENDF data
c        2  1-72    Output ENDF data - Only MF/MT=2/152 and 2/153
c        3  1-5     Output Option
c                   = 0 = Original data
c                   = 1 = No Self-Shielding
c                   = 2 = Multi-band data (replaces PTM data)
c                   = Other = interpreted as = 0
c
c     The default names for the ENDF data are the same as the
c     default names for ALL PREPRO codes.
c     1) ENDFB.IN
c     2) ENDFB.OUT
c
c=======================================================================
c
c     Bonderenko self-shielded cross section is defined as,
c
c                   integral[sig(E)*dE/{sigT(E)+sigma0}]
c     sig(sigma0) = ------------------------------------
c                   integral[dE/{sigT(E)+sigma0}]
c
c     In terms of discrete multi-band or PTM parameters the integrals
c     are replaced by weighted sums.
c
c                   sum[wtB*sigB/{sigTB+sigma0}]
c     sig(sigma0) = -------------------------------
c                   sum[wtB/{sigTB+sigma0}]
c
c     Below I define FF0 for sigma0=infinity
c                and FF1 for sigma0=0
c                and FF2 using SigTB**2 instead of SigTB,
c
c     FF0         = sum[wtB*sigB]            [Unshielded]
c
c                   sum[wtB*sigB/sigTB]
c     FF1         = ----------------------   [Flux weigthing]
c                   sum[wtB/sigTB]
c
c                   sum[wtB*sigB/sigTB]
c     FF2         = ----------------------   [Current weighting]
c                   sum[wtB/sigTB**2]
c
c     In terms of f-factors the cross sections are replaced by the
c     f-factors and in all cases the results scale by the unshielded
c     average cross section for each reaction,
c
c     FF0         = sum[wtB*f-factor] - should = 1.
c
c                   sum[wtB*f-factorTB/f-factorTB]
c     FF1         = ------------------------------
c                   sum[wtB/f-factorTB]
c
c                   sum[wtB*f-factorTB/f-factorTB**2]
c     FF2         = ---------------------------------
c                   sum[wtB/f-factorTB**2]
c
c=======================================================================
      include 'implicit.h'
      include 'urrdo.h'
      character*80 label
      character*72 filein,fileout
      character*24 pathname(3)
      character*8 codename
      integer outp,otape
      common/pathway/mypath
      common/endfio/inp,outp,itape,otape
      common/header/c1h,c2h,l1h,l2h,n1h,n2h,math,mfh,mth,noseq
      common/leader/c1, c2, l1, l2, n1, n2
      common/njoycom/LSSF,INTUNR,ICOMP
      common/namecode/codename
      common/plotcom/plottab(1000,9),nunr
      common/BMETHOD/METHODB
      data pathname/
     1 'Original Data           ',
     2 'No Shielding            ',
     3 'Multi-Band Parameters   '/
c       123456789012345678901234
c
c     Select 2 Bands method
c
      METHODB = 2
c-----------------------------------------------------------------------
c
c     Initialize and list ENDF file label
c
c-----------------------------------------------------------------------
c-----Define codename for compatibility with PREPRO
      codename = 'URRDIFF '
c-----Define ALL I/O units using PREPRO definitions
      inp   =  2
      outp  =  3
      itape = 10
      otape = 11
      open( 3,file='URRDIFF.LST')
c-----Open input parameter file
      open( 2,file='URRDIFF.INP',status='OLD',err=10)
      go to 30
c-----No input - use defaults
   10 filein  = 'ENDFB.IN'
      fileout = 'ENDFB.OUT'
   20 mypath  = 0              ! Original Data
      go to 60
c-----read input
   30 read (2,40,err=10) filein,fileout
   40 format(a72)
      if(filein .eq.'    ') filein = 'ENDFB.IN'
      if(fileout.eq.'    ') filein = 'ENDFB.OUT'
      read (2,50,err=20) mypath
      if(mypath.lt.0.or.mypath.gt.2) mypath = 0
   50 format(i5)
c-----List input parameters
   60 write(3,70) filein,fileout,pathname(mypath+1)
      write(*,70) filein,fileout,pathname(mypath+1)
   70 format(' PREPRO (2016-1) Output for MF/MT=2/152 and 2/153'/
     1       1x,71('=')/
     2       ' Read.....',a72/
     3       ' Write....',a72/
     3       ' Output...',a24/
     4       1x,71('='))
c-----Open ENDF data files and initialize.
      open(10,file=filein ,status='OLD',ERR=350)
      open(11,file=fileout,status='UNKNOWN')
      matlst = 0
      noseq  = 0
c-----Read and List ENDF file label
      read (10,80,end=350) label
      write( 3,80) label
      write( *,80) label
   80 format(a80)
c-----Replace ENDF file label on ENDF Output file
      if(mypath.eq.0) then
      write(11,90)
   90 format(' URRDIFF (2016-1): NJOY PTM MF/MT=2/152 and 2/153    ',
     1 13x,'7000 0  0    0')
      else
      if(mypath.eq.1) then
      write(11,100)
  100 format(' URRDIFF (2016-1): No Shielding MF/MT=2/l52 and 2/153',
     1 13x,'7000 0  0    0')
      else
      write(11,110)
  110 format(' URRDIFF (2016-1): NJOY MB MF/MT=2/152 and 2/153     ',
     1 13x,'7000 0  0    0')
      endif
      endif
c             1234567890123456789012345678901234567890123456789012345
c                      1         2         3         4         5
c-----------------------------------------------------------------------
c
c     Skip to MF/MT=2/152
c
c-----------------------------------------------------------------------
  120 read (10,130,end=350) c1h,c2h,l1h,l2h,n1h,n2h,math,mfh,mth
  130 format(2d11.4,4i11,i4,i2,i3)
      if(mth.gt.0) go to 140
      if(math.lt.0) go to 350
      go to 120
  140 if(mfh.eq.2.and.mth.eq.152) go to 200
  150 read (10,160,end=350) math,mfh,mth
  160 format(66x,i4,i2,i3)
      if(mth.gt.0) go to 150
      go to 120
c-----------------------------------------------------------------------
c
c     Skip to MF/MT=2/153
c
c-----------------------------------------------------------------------
  170 read (10,130,end=350) c1h,c2h,l1h,l2h,n1h,n2h,math,mfh,mth
      if(mth.gt.0) go to 180
      if(math.lt.0) go to 350
      go to 170
  180 if(mfh.eq.2.and.mth.eq.153) go to 270
  190 read (10,160,end=350) math,mfh,mth
      if(mth.gt.0) go to 190
      go to 170
c-----------------------------------------------------------------------
c
c     List MF/MT=2/152 data.
c
c-----------------------------------------------------------------------
  200 iza    = c1h
      matlst = math
      read (10,210,end=350) c1,c2,l1,l2,n1,n2
  210 format(2d11.4,4i11)
      tmpz   = c1
      write(*,220) iza,mfh,mth,tmpz
      write(3,220) iza,mfh,mth,tmpz
  220 format(1x,71('=')/' iza/mfh/mth/tmpz=',i7,i3,i4,1pd12.5,' K'/
     1 1x,71('='))
      nreac = l1
      nsigz = l2
      nunr  = n2
      LSSF  = l1h
      INTUNR= n2h
      write(*,230) n1,nreac,nsigz,nunr,LSSF,INTUNR
  230 format(' As Read'/
     1       ' n1     =',i5/
     2       ' nreac  =',i5/
     3       ' nsigz  =',i5/
     4       ' nunr   =',i5/
     4       ' LSSF   =',i5/
     4       ' INTUNR =',i5)
      call listi(x(1),n1)
c-----sigma-0 values
      ii = 0
      do isigz = 1,nsigz
      ii = ii + 1
      sigz(isigz) = x(ii)
      enddo
c-----shield x/c = vs. energy range, reaction, sigma-0
      do iunr = 1,nunr                ! energy range
      ii = ii + 1
      eunr(iunr) = x(ii)
      do ireac = 1,nreac              ! reaction
      do isigz = 1,nsigz              ! sigma0
      ii = ii + 1
      sigu(ireac,isigz,iunr) = x(ii)
      enddo
      enddo
      enddo
c-----list.
      do iunr=1,nunr
      write(3,310) eunr(iunr)
      write(3,240)
c***** DEBUG
  240 format(' Sigma-0',4x,' Total',7X,'Elastic',5X,'Fission',5x,
     1 'Capture',5x,'Other  ')
c***** DEBUG
c 240 format(' Sigma-0',4x,' Total',7X,'Elastic',5X,'Fission',5x,
c    1 'Capture',5x,'Current')
c***** DEBUG
      do isigz=1,nsigz
c***** DEBUG
      sum = 0.0
      do ii=2,nreac-1
      sum = sum + sigu(ii,isigz,iunr)
      enddo
      diff = sigu(1,isigz,iunr) - sum
      write(3,250) sigz(isigz),
     1              (sigu(ireac,isigz,iunr),ireac=1,nreac-1),diff
c***** DEBUG
c     write(3,250) sigz(isigz),
c    1              (sigu(ireac,isigz,iunr),ireac=1,nreac)
c***** DEBUG
  250 format(1p10d12.5)
      enddo
c-----List f-factors based on last and first cross sections vs. sigma0
      do ireac=1,nreac
      if(sigu(ireac,1,iunr).gt.0.0d0) then
      sum1(ireac) = sigu(ireac,nsigz,iunr)/sigu(ireac,1,iunr)
      else
      sum1(ireac) = 1.0d0
      endif
      enddo
c***** DEBUG
c     write(3,260) (sum1(ireac),ireac=1,nreac)
      write(3,260) (sum1(ireac),ireac=1,nreac-1)
c***** DEBUG
  260 format('  FF1',7x,1p10d12.5)
      enddo
c-----------------------------------------------------------------------
c
c     Output ENDF MF/MT=2/152
c
c-----------------------------------------------------------------------
      call mfmt2152
      go to 170             ! Try for next ENDF section
c-----------------------------------------------------------------------
c
c     List MF/MT=2/153 data.
c
c-----------------------------------------------------------------------
  270 iza    = c1h
      nbin   = n2h
      matlst = math
      read (10,210,end=350) c1,c2,l1,l2,n1,n2
      tmpz   = c1
      nunr   = n2
      LSSF   = l1
      INTUNR = n1h
      ICOMP  = l2
      write(*,220) iza,mfh,mth,tmpz
      write(3,220) iza,mfh,mth,tmpz
c-----WARNING on LSSF
      if(LSSF.eq.0) then
      write(*,280)
      write(3,280)
  280 format(1x,71('-')/
     1 ' WARNING - LSSF = 0 - Output is Cross Section, not f-factors'/
     1 1x,71('-'))
      else
      write(*,290)
      write(3,290)
  290 format(1x,71('-')/
     1 ' WARNING - LSSF = 1 - Output is f-factors, not Cross Section'/
     1 1x,71('-'))
      endif
      write(*,300) n1,nbin,nunr,LSSF,INTUNR,ICOMP
  300 format(' As Read'/
     1       ' n1     =',i5/
     2       ' nbin   =',i5/
     4       ' nunr   =',i5/
     4       ' LSSF   =',i5/
     4       ' INTUNR =',i5/
     4       ' ICOMP  =',i5)
      call listi(x(1),n1)
      ii = 0
      do iunr=1,nunr
      ii = ii + 1
      eunr(iunr) = x(ii)        ! lower energy
      do ipar=1,6               ! 6 parameters=P,T,E,F,C,H
      do ibin=1,nbin            ! nbin bins
      ii = ii + 1
      param(ipar,ibin,iunr) = x(ii)
      enddo
      enddo
      enddo
c
c     F-factor vs. sigma0 for first and last energies
c
      call vssigma0(nunr,nbin)
c-----List parameters
      do iunr=1,nunr             ! Loop over energy range
      write(3,310) eunr(iunr)
  310 format(1x,71('-')/1pd12.5,' eV')
      write(3,320)
  320 format('  Bin ','   Weight',3x,'Total',7X,'Elastic',5X,
     1 'Fission',5x,'Capture',5X,'Heat')
      do k=1,6
      sum0(k) = 0.0
      sum1(k) = 0.0
      sum2(k) = 0.0
      enddo
      bottom1 = 0.0
      bottom2 = 0.0
c
c     Use F = 1 or Unshielded Total
c
      if(LSSF.eq.0) then
c-----Unshielded total
      sigma0 = 0.0
      do ibin=1,nbin
      sigma0  = sigma0  + param(1,ibin,iunr)*param(2,ibin,iunr)
      enddo
      else
c-----Unshielded f = 1
      sigma0 = 1.0d0
      endif
      do ibin=1,nbin
      write(3,330) ibin,(param(ipar,ibin,iunr),ipar=1,6)
  330 format(i5,0pf12.6,1p5d12.5)
c-----------------------------------------------------------------------
c
c     FF0         = sum[wtB*f-factor] - should = 1.
c
c                   sum[wtB*f-factorB/f-factorTB]
c     FF1         = -----------------------------
c                   sum[wtB/f-factorTB]
c
c                   sum[wtB*factorB/f-factorTB]
c     FF2         = ----------------------
c                   sum[wtB/f-factrorTB**2]
c
c-----------------------------------------------------------------------
c-----Sum of Weights - should = 1.
      sum0(1) = sum0(1) + param(1,ibin,iunr)
      do k=2,6
c-----Unshielded
      sum0(k) = sum0(k) + param(1,ibin,iunr)*param(k,ibin,iunr)
c-----Flux Weighting
      sum1(k) = sum1(k) + param(1,ibin,iunr)*param(k,ibin,iunr)/
     1 param(2,ibin,iunr)
c-----Current Weighting
      if(METHODB.eq.1) then
      sum2(k) = sum2(k) + param(1,ibin,iunr)*param(k,ibin,iunr)/
     1 (param(2,ibin,iunr)**2)
      else
      sum2(k) = sum2(k) + param(1,ibin,iunr)*param(k,ibin,iunr)/
     1 (param(2,ibin,iunr) + sigma0)
      endif
      enddo
c-----denominators = same for all reactions.
      bottom1 = bottom1 + param(1,ibin,iunr)/param(2,ibin,iunr)
      if(METHODB.eq.1) then
      bottom2 = bottom2 + param(1,ibin,iunr)/(param(2,ibin,iunr)**2)
      else
      bottom2 = bottom2 + param(1,ibin,iunr)/
     1 (param(2,ibin,iunr) + sigma0)
      endif
      enddo
      do k=2,6
      sum1(k) = sum1(k)/bottom1
      sum2(k) = sum2(k)/bottom2
      enddo
      write(3,340) sum0,(sum1(k),k=2,6),(sum2(k),k=2,6)
  340 format('  FF0',0pf12.6,1p5d12.5/
     1       '  FF1',12x,1p5d12.5/
     1       '  FF2',12x,1p5d12.5)
c-----Save for PLOTTAB output.
      plottab(iunr,1) = eunr(iunr)
c
c     Insure that results are f factors, rather than cross section
c
      plottab(iunr,2) = sum1(2)/sum0(2) ! F1
      plottab(iunr,3) = sum1(3)/sum0(3)
      plottab(iunr,4) = sum1(4)/sum0(4)
      plottab(iunr,5) = sum1(5)/sum0(5)
      plottab(iunr,6) = sum2(2)/sum0(2) ! F2
      plottab(iunr,7) = sum2(3)/sum0(3)
      plottab(iunr,8) = sum2(4)/sum0(4)
      plottab(iunr,9) = sum2(5)/sum0(5)
c-----------------------------------------------------------------------
c
c     Define Multi-band Parameters.
c
c-----------------------------------------------------------------------
      call mbmaker(sum0(1),sum1(1),sum2(1),bands(1,1,iunr))
      enddo
c-----------------------------------------------------------------------
c
c     Output ENDF MF/MT=2/153
c
c-----------------------------------------------------------------------
      call mfmt2153
c-----------------------------------------------------------------------
c
c     End of run = output fend, mend and tend
c
c-----------------------------------------------------------------------
  350 if(matlst.gt.0) then
      write(11,360) matlst
  360 format(66x,i4, ' 0  0    0'/    ! fend
     1       66x,'   0 0  0    0'/    ! mend
     2       66x,'  -1 0  0    0')    ! tend
      call plotit
      call endit
      else
      write(*,370)
      write(3,370)
  370 format(///' ERROR - Reading ENDF Data'/
     1          '         No Output Created'///)
      call enderror
      endif
      end
      subroutine vssigma0(nunr,nbin)
c=======================================================================
c
c     PLOTTAB formatted output of f-factor vs. sigma0
c
c=======================================================================
      include 'implicit.h'
      include 'urrdo.h'
      dimension sig0(41)
      open(17,file='VS-SIGMA0.CUR')
c-----define sigma0 as multiple of unshielded
      xx = 1.0d0/1024.0d0
      dx = dsqrt(2.d0)
      do i=1,41
      sig0(i) = xx
      xx      = dx*xx
      enddo
c-----do first and last energies.
      do loop=1,2
      iunr = 1
      if(loop.eq.2) iunr = nunr
c-----define normalization
      fnorm = 0.0d0
      do ibin=1,nbin
      fnorm = fnorm + param(1,ibin,iunr)*param(2,ibin,iunr)
      enddo
      write(17,10) nbin,eunr(iunr)
   10 format(i3,' Bins',0pf8.0,' eV')
      do isig=1,41
      top    = 0.0d0
      bottom = 0.0d0
      do ibin=1,nbin
c-----Only use f-factors to properly scale sig0
      pp2    = param(2,ibin,iunr)/fnorm
      basic  = param(1,ibin,iunr)/(pp2 + sig0(isig))
      top    = top    + basic*pp2
      bottom = bottom + basic
      enddo
      fnow   = top/bottom
      write(17,20) sig0(isig),fnow
   20 format(1p2d11.4)
      enddo
      write(17,30)
   30 format(30x,'(BLANK LINE)')
      enddo
      return
      end
      subroutine plotit
c=======================================================================
c
c     F1 and F2 versus Energy.
c
c=======================================================================
      include 'implicit.h'
      common/plotcom/plottab(1000,9),nunr
      character*8 react(4)
      data react/
     1 'Total   ',
     1 'Elastic ',
     1 'Fission ',
     1 'Capture '/
      open(16,file='VS-ENERGY.CUR')
      do ireact=1,4
      write(16,10) react(ireact)
   10 format(a8,' F1 NJOY')
      do i=1,nunr
      write(16,30) plottab(i,1),plottab(i,ireact+1)
      enddo
      write(16,40)
      write(16,20) react(ireact)
   20 format(a8,' F2 NJOY')
      do i=1,nunr
      write(16,30) plottab(i,1),plottab(i,ireact+5)
      enddo
      write(16,40)
      enddo
      return
   30 format(1p2d11.4)
   40 format(30x,'(BLANK LINE)')
      end
      subroutine mbmaker(sum0,sum1,sum2,bands)
c=======================================================================
c
c     Create Multi-Band Parameters
c
c     Verified vs. GROUPIE and Output here.
c
c=======================================================================
      include 'implicit.h'
      common/BMETHOD/METHODB
      dimension sum0(6),sum1(6),sum2(6),bands(2,6),FXTAB(3,6)
c-----------------------------------------------------------------------
c
c     Method #1: Total Parameters.
c
c     Conserve F0, F1 and F2
c
c     SIG1X = SIG1T^2
c     SIG2X = SIG2T^2
c F0 = P1*SIG1T         + P2*SIG2T
c F1 =(P1*SIG1T/SIG1T   + P2*SIG2T/SIG2T  )/(P1/SIG1T   + P2/SIG2T  )
c F2 =(P1*SIG1T/SIG1X   + P2*SIG2T/SIG2X  )/(P1/SIG1X   + P2/SIG2X  )
c
c-----------------------------------------------------------------------
c-----------------------------------------------------------------------
c
c     Method #2: Total Parameters.
c
c     Conserve F0, F1 and F2 = 1/[total + <total>]
c
c     SIG1X = SIG1T + SIGMA0
c     SIG2X = SIG2T + SIGMA0
c F0 = P1*SIG1T         + P2*SIG2T
c F1 =(P1*SIG1T/SIG1T   + P2*SIG2T/SIG2T  )/(P1/SIG1T   + P2/SIG2T  )
c F2 =(P1*SIG1T/SIG2X   + P2*SIG2T/SIG2X  )/(P1/SIG1X   + P2/SIG2X  )
c
c-----------------------------------------------------------------------
      F0 = sum0(2)
      F1 = sum1(2)
      F2 = sum2(2)
c-----------------------------------------------------------------------
c
c     Little Self-Shielding Limit = set to no shielding.
c     or ERRORS = F0, F1, F2 NOT POSITIVE.
c
c-----------------------------------------------------------------------
      if(F0.le.0.0d0.or.F1.le.0.0d0.or.F2.le.0.0d0) go to 10
      if(METHODB.eq.1) then
      if(F1.lt.0.9999*F0.and.
     1   F2.lt.0.9999*F0) go to 20   ! F2 is lower
      else
c-----Note, stricter method#2
      if(F1.lt.0.9999 *F0.and.
     1   F2.lt.0.99999*F0) go to 20   ! F1 is lower
      endif
c-----------------------------------------------------------------------
c
c     No Shielding - May loop back here if fit does not work
c
c-----------------------------------------------------------------------
   10 bands(1,1) = 0.5d0
      bands(2,1) = 0.5d0
      do k=2,6
      bands(1,k) = sum0(k)
      bands(2,k) = sum0(k)
      FXTAB(1,k) = sum0(k)
      FXTAB(2,k) = sum0(k)
      FXTAB(3,k) = sum0(k)
      enddo
      go to 30
c-----------------------------------------------------------------------
c
c     Normal Case - Insure ALL parameters are physically possible =
c     cross sections and weights are ALL positive.
c
c     If fit does not work using NO SHIELDING
c
c-----------------------------------------------------------------------
   20 top    = F0 - F2
      bottom = F0 - F1
      if(METHODB.eq.1) then
      A      = 0.5d0*top/(F2*bottom)
      else
      A      = 0.5d0*bottom/(F1*top)
      endif
      ARG    = DABS ((F1*A*(F0*A-2.0d0)+1.0d0)/(F0*F1)) ! GROUPIE =O.K.
      B      = dsqrt(ARG)
c
c     Insure results are physically acceptable =
c     Weights and Cross Sections MUST BE POSITIVE.
c
      if(B.gt.0.9999*A) B = 0.9999*A         ! BIG self-shielding
      D      = (1.0d0 - A*F1)/(2.0d0*B*F1)
      if(D.gt. 0.4999) D = 0.4999          ! BIG self-shielding
      if(D.lt.-0.4999) D =-0.4999
c
c     Define final results.
c
      P1     = 0.5d0 + D
      P2     = 0.5d0 - D
      SIG1T  = 1.0d0/(A+B)
      SIG2T  = 1.0d0/(A-B)
c
c     Insure EXACT unshielded: F0 = P1*SIG1T + P2*SIG2T
c     P1 + P2 = 1 = guaranteed from above definition.
c     Use SIG1T and SIG2T to EXACTLY re-normalize.
c
      F0X = P1*SIG1T + P2*SIG2T
      F0N = F0/F0X
      SIG1T = F0N*SIG1T
      SIG2T = F0N*SIG2T
c
c     Save Parameters for output.
c
      bands(1,1) = P1
      bands(2,1) = P2
      bands(1,2) = SIG1T
      bands(2,2) = SIG2T
c
c     CHECK
c
      F0X = P1*SIG1T + P2*SIG2T
      SS  = P1/SIG1T + P2/SIG2T
      F1X = 1.0/SS
      if(METHODB.eq.1) then
      SIG1X = SIG1T**2
      SIG2X = SIG2T**2
      else
      SIG1X = SIG1T + F0
      SIG2X = SIG2T + F0
      endif
      XX1 = P1*SIG1T/SIG1X + P2*SIG2T/SIG2X
      XX2 = P1      /SIG1X + P2      /SIG2X
      F2X = XX1/XX2
      FXTAB(1,2) = F0X
      FXTAB(2,2) = F1X
      FXTAB(3,2) = F2X
c-----------------------------------------------------------------------
c
c     Partial Parameters.
c
c     Conserve F0R and F1R - Insure cross sections are positive.
c
c     F0R = P1*SIG1R       + P2*SIG2R
c     F1R =(P1*SIG1R/SIG1T + P2*SIG2R/SIG2T)/(P1/SIG1T+P2/SIG2T)
c
c-----------------------------------------------------------------------
      BOTTOM1 = P1/SIG1T    + P2/SIG2T
c-----No METHODB test necessary - SIG1X and SIG2X are correct.
      BOTTOM2 = P1/SIG1X    + P2/SIG2X
      DIFF    =(1.0d0/SIG1T - 1.0d0/SIG2T)*F1
      do k=3,6
      F0R = sum0(k)
      F1R = sum1(k)
      F2R = sum2(k)
c
c     No Negative Cross Sections.
c
      if(F0R.le.0.0) then
      F0R = 0.0d0
      F1R = 0.0d0
      F2R = 0.0d0
      endif
c
c     Any value of C will conserve unshielded average.
c     Try to also conserve totally shielded average,
c     but limit C to physical range for cross sections > 0
c
      if(DIFF.eq.0.0d0) then
      SIG1R = F0R               ! No Shielding
      SIG2R = F0R
      else
      C = (F0R - F1R)/DIFF
      if(C.gt.0.0d0) then
      if(C.gt. 0.999*P1*F0R) C = 0.999*P1*F0R ! BIG self-shielding
      else
      if(C.lt.-0.999*P2*F0R) C =-0.999*P2*F0R
      endif
      SIG1R = F0R - C/P1 ! With above constraints these MUST be > 0
      SIG2R = F0R + C/P2
      endif
c
c     Save results
c
      bands(1,k) = SIG1R
      bands(2,k) = SIG2R
c
c     Check
c
      F0RX =  P1*SIG1R          + P2*SIG2R
      F1RX = (P1*SIG1R/SIG1T    + P2*SIG2R/SIG2T)/BOTTOM1
      F2RX = (P1*SIG1R/SIG1X    + P2*SIG2R/SIG2X   )/BOTTOM2
      FXTAB(1,k) = F0RX
      FXTAB(2,k) = F1RX
      FXTAB(3,k) = F2RX
      enddo
c
c     Print Summary
c
   30 write(3,40) ((FXTAB(kk,kkk),kkk=2,6),kk=1,3)
   40 format(1X,71('-')/
     1 ' FF0X',12x,1p5d12.5/
     1 ' FF1X',12x,1p5d12.5/
     1 ' FF2X',12x,1p5d12.5)
      return
      end
      subroutine mfmt2152
c=======================================================================
c
c     Output MF/MT=2/152
c
c=======================================================================
      include 'implicit.h'
      include 'urrdo.h'
      character*80 label
      common/pathway/mypath
      common/header/c1h,c2h,l1h,l2h,n1h,n2h,math,mfh,mth,noseq
      common/leader/c1, c2, l1, l2, n1, n2
c-----------------------------------------------------------------------
c
c     Select path,
c     0) Original Data
c     1) No Shielding
c     2) Multi-band    = Same as Original Data
c
c-----------------------------------------------------------------------
      nreac = l1
      nsigz = l2
      nunr  = n2
      LSSF  = l1h
      INTUNR= n2h
      ii = 0
      do isigz = 1,nsigz
      ii = ii + 1
c     sigz(isigz) = x(ii)
      x(ii) = sigz(isigz)
      enddo
c-----shield x/c = vs. energy range, reaction, sigma-0
      do iunr = 1,nunr                ! energy range
      ii = ii + 1
c     eunr(iunr) = x(ii)
      x(ii) = eunr(iunr)
      do ireac = 1,nreac              ! reaction
      do isigz = 1,nsigz              ! sigma0
      ii = ii + 1
c     sigu(ireac,isigz,iunr) = x(ii)
      x(ii) = sigu(ireac,isigz,iunr)
      if(mypath.eq.1) x(ii) = sigu(ireac,1,iunr) ! No Shielding
      enddo
      enddo
      enddo
c-----------------------------------------------------------------------
c
c     Output in ENDF format
c
c-----------------------------------------------------------------------
      n1 = ii
      write(*,10) n1,nreac,nsigz,nunr,LSSF,INTUNR
   10 format(' As Written'/
     1       ' n1     =',i5/
     2       ' nreac  =',i5/
     3       ' nsigz  =',i5/
     4       ' nunr   =',i5/
     4       ' LSSF   =',i5/
     4       ' INTUNR =',i5)
      call conto
      call cardo(c1,c2,l1,l2,n1,n2)
      call listo9(x(1),n1)
      call outs(math,mfh)
      return
      end
      subroutine mfmt2153
c=======================================================================
c
c     Output MF/MT=2/153
c
c=======================================================================
      include 'implicit.h'
      include 'urrdo.h'
      character*80 label
      common/pathway/mypath
      common/header/c1h,c2h,l1h,l2h,n1h,n2h,math,mfh,mth,noseq
      common/leader/c1, c2, l1, l2, n1, n2
      dimension ssdum(6)
c-----------------------------------------------------------------------
c
c     Select path,
c     0) Original Data
c     1) No Shielding   = Set all f-factors = 1.0
c     2) Multi-band
c
c-----------------------------------------------------------------------
      nunr   = n2                 ! # of energies = always the same
      LSSF   = l1
      ICOMP  = l2
      INTUNR = n1h
      if(mypath.eq.2) go to 10
c-----------------------------------------------------------------------
c
c     Output Original or No Shielding PTM Parameters
c
c-----------------------------------------------------------------------
      nbin   = n2h
c-----initialize for f-factors
      do i=1,6
      ssdum(i) = 1.0d0
      enddo
c-----loop over energies.
      ii = 0
      do iunr=1,nunr
      ii = ii + 1
c     eunr(iunr) = x(ii)        ! lower energy
      x(ii) = eunr(iunr)        ! lower energy
c-----if cross section output define unshielded averages
      if(mypath.eq.1.and.LSSF.eq.0) then
      do ipar=2,6               ! 6 parameters=P,T,E,F,C,H
      xx = 0.0
      do ibin=1,nbin
      xx = xx + param(1,ibin,iunr)*param(ipar,ibin,iunr)
      enddo
      ssdum(ipar) = xx
      enddo
      endif
c-----all cases
      do ipar=1,6               ! 6 parameters=P,T,E,F,C,H
      do ibin=1,nbin            ! nbin bins
      ii = ii + 1
c     param(ipar,ibin,iunr) = x(ii)
      x(ii) = param(ipar,ibin,iunr)
      if(mypath.eq.1.and.ipar.gt.1) x(ii) = ssdum(ipar) ! No Shielding
      enddo
      enddo
      enddo
      go to 20
c-----------------------------------------------------------------------
c
c     Output multi-band Data.
c
c-----------------------------------------------------------------------
   10 nbin = 2
      n2h  = nbin
      ii = 0
      do iunr=1,nunr
      ii = ii + 1
c     eunr(iunr) = x(ii)        ! lower energy
      x(ii) = eunr(iunr)        ! lower energy
      do ipar=1,6               ! 6 parameters=P,T,E,F,C,H
      do ibin=1,nbin            ! nbin bins
      ii = ii + 1
c     param(ipar,ibin,iunr) = x(ii)
      x(ii) = bands(ibin,ipar,iunr)
      enddo
      enddo
      enddo
c-----------------------------------------------------------------------
c
c     Output in ENDF format
c
c-----------------------------------------------------------------------
   20 n1     = ii
      write(*,30) n1,nbin,nunr,LSSF,INTUNR,ICOMP
   30 format(' As Written'/
     1       ' n1     =',i5/
     2       ' nbin   =',i5/
     3       ' nunr   =',i5/
     3       ' LSSF   =',i5/
     3       ' INTUNR =',i5/
     3       ' ICOMP  =',i5)
      call conto
      call cardo(c1,c2,l1,l2,n1,n2)
      call listo9(x(1),n1)
      call outs(math,mfh)
      return
      end
      SUBROUTINE ENDIT
C=======================================================================
C
C     NORMAL END - Print code name but NO TIME.
C
C=======================================================================
      IMPLICIT REAL*4 (A-H,O-Z)  ! note - REAL*4 not 8
      IMPLICIT INTEGER*4 (I-N)
      SAVE
      CHARACTER*8 CODENAME
      COMMON/NAMECODE/CODENAME
      WRITE(3,10) CODENAME
      WRITE(*,10) CODENAME
      STOP
C=======================================================================
C
C     ERROR END - Print ERROR message but NO TIME.
C
C=======================================================================
      ENTRY ENDERROR
      WRITE(3,20)
      WRITE(*,20)
   10 FORMAT(1X,71('=')/1X,A8/1X,71('='))
   20 FORMAT(1X,71('=')/1X,'   ERROR'/1X,71('='))
      STOP
      END
      SUBROUTINE CONTO
C=======================================================================
C
C     WRITE ONE ENDF/B CONTROL RECORD.
C
C=======================================================================
      INCLUDE 'implicit.h'
      INTEGER*4 OUTP,OTAPE
      CHARACTER*1 FIELD2
      COMMON/ENDFIO/INP,OUTP,ITAPE,OTAPE
      COMMON/HEADER/C1H,C2H,L1H,L2H,N1H,N2H,MATH,MFH,MTH,NOSEQ
      DIMENSION FIELD2(11,2)
C-----LAST MAT NUMBER - USED TO RESET SEQUENCE NUMBER
      DATA LASTMAT/-100000/
C-----NO OUTPUT IF OUTPUT UNIT IS TURNED OFF
      IF(OTAPE.LE.0) RETURN
C-----IF SEND, FEND OR MEND OUTPUT IN STANDARD FORM.
      IF(MTH.GT.0) GO TO 10
      CALL OUTS(MATH,MFH)
      RETURN
C-----CONVERT FLOATING POINT NUMBERS TO STANDARD OUTPUT FORM.
   10 CALL OUT9(C1H,FIELD2(1,1))
      CALL OUT9(C2H,FIELD2(1,2))
C-----ELIMINATE -0
      IF(IABS(L1H).LE.0) L1H=0
      IF(IABS(L2H).LE.0) L2H=0
      IF(IABS(N1H).LE.0) N1H=0
      IF(IABS(N2H).LE.0) N2H=0
C-----IF NEW MAT RESET SEQUENCE NUMBER
      IF(MATH.eq.LASTMAT) go to 20
      LASTMAT=MATH
      NOSEQ=1
C-----OUTPUT LINE IMAGE.
   20 IF(NOSEQ.LE.0) NOSEQ=1
      WRITE(OTAPE,30) FIELD2,L1H,L2H,N1H,N2H,MATH,MFH,MTH,NOSEQ
      NOSEQ=NXTSEQ(NOSEQ)
      RETURN
   30 FORMAT(22A1,4I11,I4,I2,I3,I5)
      END
      SUBROUTINE CARDO(C1,C2,L1,L2,N1,N2)
C=======================================================================
C
C     WRITE ENDF/B LINE.
C
C=======================================================================
      INCLUDE 'implicit.h'
      INTEGER*4 OUTP,OTAPE
      CHARACTER*1 FIELD2
      COMMON/ENDFIO/INP,OUTP,ITAPE,OTAPE
      COMMON/HEADER/C1H,C2H,L1H,L2H,N1H,N2H,MATH,MFH,MTH,NOSEQ
      DIMENSION FIELD2(11,2)
C-----NO OUTPUT IF OUTPUT UNIT IS TURNED OFF
      IF(OTAPE.LE.0) RETURN
      IF(MTH.GT.0) GO TO 10
      CALL OUTS(MATH,MFH)
      RETURN
C-----CONVERT FLOATING POINT NUMBERS TO STANDARD OUTPUT FORM.
   10 CALL OUT9(C1,FIELD2(1,1))
      CALL OUT9(C2,FIELD2(1,2))
C-----ELIMINATE -0
      IF(IABS(L1).LE.0) L1=0
      IF(IABS(L2).LE.0) L2=0
      IF(IABS(N1).LE.0) N1=0
      IF(IABS(N2).LE.0) N2=0
C-----OUTPUT LINE.
      IF(NOSEQ.LE.0) NOSEQ=1
      WRITE(OTAPE,20) FIELD2,L1,L2,N1,N2,MATH,MFH,MTH,NOSEQ
      NOSEQ=NXTSEQ(NOSEQ)
      RETURN
   20 FORMAT(22A1,4I11,I4,I2,I3,I5)
      END
      SUBROUTINE LISTI(X,IX)
C=======================================================================
C
C     READ LIST DATA.
C
C=======================================================================
      INCLUDE 'implicit.h'
      INTEGER*4 OUTP,OTAPE
      CHARACTER*1 FIELD6
      COMMON/ENDFIO/INP,OUTP,ITAPE,OTAPE
      DIMENSION X(IX),FIELD6(11,6)
C
C     READ LIST RECORD PARAMETERS
C
C-----SET UP LOOP OVER CARDS.
      DO 20 I1=1,IX,6
      I2=I1+5
      IF(I2.GT.IX) I2=IX
C-----READ AS CHARACTERS
      READ(ITAPE,30) FIELD6
C-----CONVERT FROM CHARACTERS TO FLOATING POINT
      K=0
      DO 10 L=I1,I2
      K=K+1
   10 CALL IN9(X(L),FIELD6(1,K))
   20 CONTINUE
      RETURN
   30 FORMAT(66A1)
      END
      SUBROUTINE LISTO9(X,IX)
C=======================================================================
C
C     WRITE LIST DATA
C
C     SAME AS LISTO, BUT USE OUT9G NOT OUT10.
C
C=======================================================================
      INCLUDE 'implicit.h'
      INTEGER*4 OUTP,OTAPE
      CHARACTER*1 FIELD6
      COMMON/ENDFIO/INP,OUTP,ITAPE,OTAPE
      COMMON/HEADER/C1H,C2H,L1H,L2H,N1H,N2H,MATH,MFH,MTH,NOSEQ
      DIMENSION X(IX),FIELD6(11,6)
C-----NO OUTPUT IF OUTPUT UNIT IS TURNED OFF
      IF(OTAPE.LE.0) RETURN
C-----NOTHING TO DO IF NO POINTS TO OUTPUT
      IF(IX.LE.0) RETURN
C-----SET UP LOOP OVER CARDS.
      DO 80 I1=1,IX,6
      I2=I1+5
      IF(I2.GT.IX) I2=IX
C-----CONVERT DATA TO NORMAL FORM.
      K=0
      DO 10 L=I1,I2
      K=K+1
c-----USE OUT9G - NOT OUT10.
   10 CALL OUT9G(X(L),FIELD6(1,K))
C-----OUTPUT ONE LINE.
      GO TO (20,30,40,50,60,70),K
   20 WRITE(OTAPE,90)   (FIELD6(M,1),M=1,11),
     1 MATH,MFH,MTH,NOSEQ
      GO TO 80
   30 WRITE(OTAPE,100) ((FIELD6(M,II),M=1,11),II=1,2),
     1 MATH,MFH,MTH,NOSEQ
      GO TO 80
   40 WRITE(OTAPE,110) ((FIELD6(M,II),M=1,11),II=1,3),
     1 MATH,MFH,MTH,NOSEQ
      GO TO 80
   50 WRITE(OTAPE,120) ((FIELD6(M,II),M=1,11),II=1,4),
     1 MATH,MFH,MTH,NOSEQ
      GO TO 80
   60 WRITE(OTAPE,130) ((FIELD6(M,II),M=1,11),II=1,5),
     1 MATH,MFH,MTH,NOSEQ
      GO TO 80
   70 WRITE(OTAPE,140) ((FIELD6(M,II),M=1,11),II=1,6),
     1 MATH,MFH,MTH,NOSEQ
   80 NOSEQ=NXTSEQ(NOSEQ)
      RETURN
   90 FORMAT(11A1,55X,I4,I2,I3,I5)
  100 FORMAT(22A1,44X,I4,I2,I3,I5)
  110 FORMAT(33A1,33X,I4,I2,I3,I5)
  120 FORMAT(44A1,22X,I4,I2,I3,I5)
  130 FORMAT(55A1,11X,I4,I2,I3,I5)
  140 FORMAT(66A1    ,I4,I2,I3,I5)
      END
      SUBROUTINE OUTT
C=======================================================================
C
C     OUTPUT TEND, MEND, FEND OR SEND RECORDS.
C     ENTRY POINTS ARE,
C     OUTT = OUTPUT TEND RECORD
C     OUTM = OUTPUT MEND RECORD
C     OUTF = OUTPUT FEND RECORD
C     OUTS = OUTPUT SEND RECORD
C
C     OUTPUT TEND RECORD
C
C=======================================================================
      INCLUDE 'implicit.h'
      INTEGER*4 OUTP,OTAPE
      COMMON/ENDFIO/INP,OUTP,ITAPE,OTAPE
      COMMON/HEADER/C1H,C2H,L1H,L2H,N1H,N2H,MATH,MFH,MTH,NOSEQ
C-----NO OUTPUT IF OUTPUT UNIT IS TURNED OFF
      IF(OTAPE.LE.0) RETURN
      WRITE(OTAPE,10)
      RETURN
C=======================================================================
C
C     OUTPUT MEND RECORD
C
C=======================================================================
      ENTRY OUTM
C-----NO OUTPUT IF OUTPUT UNIT IS TURNED OFF
      IF(OTAPE.LE.0) RETURN
      WRITE(OTAPE,20)
C-----RESET NOSEQ AFTER MEND OUTPUT
      NOSEQ=1
      RETURN
C=======================================================================
C
C     OUTPUT FEND RECORD
C
C=======================================================================
      ENTRY OUTF(MATOUT)
C-----NO OUTPUT IF OUTPUT UNIT IS TURNED OFF
      IF(OTAPE.LE.0) RETURN
      WRITE(OTAPE,30) MATOUT
      NOSEQ=1
      RETURN
C=======================================================================
C
C     OUTPUT SEND RECORD
C
C=======================================================================
      ENTRY OUTS(MATOUT,MFOUT)
C-----NO OUTPUT IF OUTPUT UNIT IS TURNED OFF
      IF(OTAPE.LE.0) RETURN
C-----NOSEQ = 0 ON FEND/MEND/TEND LINE
      IF(MFOUT.LE.0) then
      WRITE(OTAPE,30) MATOUT
      else
      WRITE(OTAPE,40) MATOUT,MFOUT  ! NOSEQ = 99999
      endif
      NOSEQ=1
      RETURN
   10 FORMAT(66X,'  -1 0  0    0')
   20 FORMAT(66X,'   0 0  0    0')
   30 FORMAT(66X,I4, ' 0  0    0')
   40 FORMAT(66X,I4,I2,'  099999')
      END
      SUBROUTINE IN9(E,FIELD)
C=======================================================================
C
C     PURPOSE
C     =======
C     CONVERT FROM HOLLERITH TO FLOATING POINT.
C     12/18/2012 - EXTENDED FOR 3 DIGIT EXPONENT (I Thank Viktor Zerkin)
C                  More than 3 digit exponent = ERROR - return 0.0
C
C     ARGUMENTS
C     =========
C     E       = FLOATING POINT NUMBER (OUTPUT)
C     FIELD   = 11A1 CHARACTER STRING (INPUT)
C
C     METHOD
C     ======
C     FIELD IS A STRING OF 11 CHARACTERS.
C     IT IS CONVERTED INTO A FLOATING POINR NUMBER (E)
C
C=======================================================================
      implicit real*8 (a-h,o-z)
      implicit integer*4 (i-n)
      save
      CHARACTER*1 MESS,DIGIT,FIELD,IFIELD
C-----12/18/2012 - EXTENDED FOR 3 DIGIT EXPONENTS
      DIMENSION FIELD(11),TENS(-99:99),DIGIT(0:9),MESS(11),XDIG(0:9)
      DATA MESS/' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' '/
      DATA DIGIT/'0','1','2','3','4','5','6','7','8','9'/
      DATA XDIG/0.0D+00,1.0D+00,2.0D+00,3.0D+00,4.0D+00,
     1          5.0D+00,6.0D+00,7.0D+00,8.0D+00,9.0D+00/
C-----ON FIRST CALL DEFINE POWERS OF 10
      DATA IPASS/0/
      IF(IPASS.NE.0) GO TO 20
      IPASS=1
      TENS(0)=1.0D+00
C-----12/18/2012 - EXTENDED FOR 3 DIGIT EXPONENTS
      DO 10 I=1,99
      TENS( I)=TENS(I-1)*10.0D+00
   10 TENS(-I)=TENS(1-I)/10.0D+00
C
C     TRANSLATE MANTISSA.
C
C-----SKIP LEADING BLANK CHARACTERS.
   20 DO 30 I=1,11
      IF(FIELD(I).NE.' ') GO TO 40
   30 CONTINUE
C-----FIELD IS COMPLETELY BLANK. RETURN ZERO.
      E=0.0D+00
      RETURN
C-----INITIALIZE SIGN TO PLUS AND THEN CHECK FOR LEADING MINUS SIGN.
   40 SIGN=1.0D+00
C-----06/02/09 - ADDED TEST FOR LEADING + SIGN.
      IF(FIELD(I).NE.'-') GO TO 50
      SIGN=-1.0D+00
      I=I+1
c-----added leading +
      GO TO 60
   50 IF(FIELD(I).EQ.'+') I = I + 1
C-----INITIALIZE FIXED POINT INPUT FIELD AND POSITION OF DECIMAL POINT.
   60 X9IN=0.0
      IPT=-20
      IMZERO=0
C-----SCAN REMAINDER OF MANTISSA.
      DO 120 J=I,11
      IFIELD=FIELD(J)
C-----SCAN FOR DIGIT OR DECIMAL POINT (WHICH ARE PART OF MANTISSA).
      DO 70 K=0,9
      IF(IFIELD.EQ.DIGIT(K)) GO TO 90
   70 CONTINUE
      IF(IFIELD.NE.'.') GO TO 80
      IPT=0
      GO TO 120
C-----SCAN FOR BLANK (WHICH ENDS MANTISSA).
   80 IF(IFIELD.EQ.' ') GO TO 130
C-----SCAN FOR e, E, d, D, - OR + (WHICH BEGINS EXPONENT).
      IF(IFIELD.EQ.'e'.OR.IFIELD.EQ.'E') GO TO 160
      IF(IFIELD.EQ.'d'.OR.IFIELD.EQ.'D') GO TO 160
      IF(IFIELD.EQ.'-') GO TO 190
      IF(IFIELD.EQ.'+') GO TO 170
C-----ERROR. CANNOT IDENTIFY CHARACTER.
      GO TO 240
C-----DIGIT FOUND. SAVE TRAILING ZEROES AFTER DECIMAL POINT.
   90 IF(IPT.LT.0) GO TO 110
      IF(K.NE.0) GO TO 100
C-----SAVE TRAILING ZEROES.
      IMZERO=IMZERO+1
      GO TO 120
  100 IF(IMZERO.LE.0) GO TO 110
C-----INSERT ZEROES BEFORE NEXT NUMBER.
      X9IN=10.0D+00*X9IN
      IPT=IPT+1
      IMZERO=IMZERO-1
      GO TO 100
C-----DIGIT FOUND. INCREMENT FIXED POINT EQUIVALENT AND DECIMAL POINT
C-----OFFSET.
  110 X9IN=10.0D+00*X9IN+XDIG(K)
      IPT=IPT+1
  120 CONTINUE
C-----ENTIRE FIELD TRANSLATED (NO EXPONENT). CONVERT TO FLOATING POINT.
      GO TO 150
C-----BLANK FOUND (END OF MANTISSA). SCAN REMAINDER OF FIELD FOR
C-----EXPONENT.
  130 I=J+1
      IF(I.GT.11) GO TO 150
      DO 140 J=I,11
      IFIELD=FIELD(J)
      IF(IFIELD.EQ.' ') GO TO 140
      IF(IFIELD.EQ.'e'.OR.IFIELD.EQ.'E') GO TO 160
      IF(IFIELD.EQ.'d'.OR.IFIELD.EQ.'D') GO TO 160
      IF(IFIELD.EQ.'-') GO TO 190
      IF(IFIELD.EQ.'+') GO TO 170
C-----ERROR. CANNOT IDENTIFY CHARACTER.
      GO TO 240
  140 CONTINUE
C-----ENTIRE FIELD TRANSLATED (NO EXPONENT). CONVERT TO FLOATING POINT.
  150 E=X9IN
      IF(IPT.GT.0) E=E/TENS(IPT)
      E=SIGN*E
      RETURN
C
C     TRANSLATE EXPONENT.
C
C-----BEGINNING OF EXPONENT FOUND (E OR D). CHECK FOR FOLLOWING - OR +.
  160 J=J+1
      IFIELD=FIELD(J)
      IF(IFIELD.EQ.'-') GO TO 190
      IF(IFIELD.NE.'+') GO TO 180
C----- + FOUND. INITIALIZE EXPONENT SIGN.
  170 J=J+1
  180 ISIGN=1
      GO TO 200
C----- - FOUND. INITIALIZE EXPONENT SIGN.
  190 J=J+1
      ISIGN=-1
C-----INITIALIZE EXPONENT AND SCAN REMAINING CHARACTERS FOR EXPONENT.
  200 IEXP=0
      DO 230 I=J,11
      IFIELD=FIELD(I)
      IF(IFIELD.EQ.' ') GO TO 230
      DO 210 K=0,9
      IF(IFIELD.EQ.DIGIT(K)) GO TO 220
  210 CONTINUE
C-----ERROR. CANNOT IDENTIFY CHARACTER.
      GO TO 240
C-----DIGIT FOUND. INCREMENT EXPONENT.
C-----OFFSET.
  220 IEXP=10*IEXP+K
  230 CONTINUE
C-----ENTIRE FIELD TRANSLATED (WITH EXPONENT). CONVERT TO FLOATING
C-----POINT.
      E=X9IN
      IEXP=ISIGN*IEXP
      IF(IPT.GT.0) IEXP=IEXP-IPT
C-----12/18/2012 - EXTENDED FOR 3 DIGIT EXPONENTS
C-----11/22/2013 - Restricted to 2 Digit Eexponent
      IF(iabs(IEXP).GT.99) GO TO 240
      E=SIGN*E*TENS(IEXP)
      RETURN
C
C     ERROR CONDITIONS.
C
C-----ILLEGAL CHARACTER.
  240 MESS(J)='*'
      write(*,250) FIELD,MESS
  250 FORMAT(1X,11A1/1X,11A1/' ERROR in Input Data...Translated as 0.')
      E=0.0D+00
      MESS(J)=' '
      RETURN
      END
      SUBROUTINE OUT9(ZIN,FIELD)
C=======================================================================
C
C     PURPOSE
C     =======
C     FORMAT NUMBER FOR OUTPUT TO INCLUDE AS MANY DIGITS OF
C     ACCURACY AS POSSIBLE.
C     12/18/2012 - EXTENDED FOR 3 DIGIT EXPONENT
C                  No test for 4 or more digit exponent
C     10/25/2014 - Changed from D to E exponential form to improve
C                  compatibility between computer languages
C
C     040923 - CHANGED ZLOW FROM 1.0D-4 TO 1.0D-3
C              NEAR 1.0D-3 PRECISION GOES FROM 999,999 TO 1,000,000
C              FOR SMOOTHEST TRANSITION FROM 6 TO 7 DIGITS
C
C     ARGUMENTS
C     =========
C     Z        = FLOATING POINT NUMBER OF BE OUTPUT (INPUT)
C     FIELD    = 11A1 CHARACTERS TO OUTPUT          (OUTPUT)
C
C     METHOD
C     ======
C     COLUMNS            12345678901     ACCURACY
C     -------------------------------------------
C     0 TO 10^-9          1.2345E-12     5 DIGITS
C     10^-9 TO 10^-3      1.23456E-8     6 DIGITS
C     10^-3 TO 10^-2      .001234567     7 DIGITS
C     10^-2 TO 10^-1      .012345678     8 DIGITS
C     10^-1 TO 1          .123456789     9 DIGITS
C     1 TO 10^9           12345.6789     9 DIGITS
C     10^9 TO 10^10       1.23456E+9     6 DIGITS
C     10^10 >             1.2345E+12     5 DIGITS
C
C     OUTPUT WILL BE IN 11 COLUMN FORMAT
C
C     WARNING - THIS IS NOT A GENERAL ROUNDING ROUTINE WHICH WILL WORK
C               FOR ROUNDING TO ANY NUMBER OF DIGITS - IT WILL ONLY
C               WORK PROPERLY FOR THE RANGES INDICATED ABOVE, FOR
C               11 COLUMN OUTPUT.
C
C=======================================================================
      implicit real*8 (a-h,o-z)
      implicit integer*4 (i-n)
      save
c-----INTEGER*8 for long integers
      integer*8 INMANT,INMAN9,INMAN8,INMAN7,INMAN6,INMAN5,INMAN4
      CHARACTER*1 FIELD,DIGITS,ZEROH
C-----12/18/2012 - EXTENDED FOR 3 DIGIT EXPONENT
      DIMENSION DIGITS(0:9),FIELD(11),ZEROH(11),
     1 TENS(-99:99),ROUNDER(-99:99)
      DATA DIGITS/
     1 '0','1','2','3','4','5','6','7','8','9'/
C-----RETURN FOR = 0
      DATA ZEROH/
     1 ' ','0','.','0',' ',' ',' ',' ',' ',' ',' '/
C-----LOWER TRANSITION POINT FROM 7 TO 9 DIGIT OUTPUT
      DATA ZLOW/1.0D-03/
C-----UPPER TRANSITION POINT FROM 9 TO 7 DIGIT OUTPUT
      DATA ZHIGH/1.0D+09/
      DATA TENTH/1.0D-01/
c-----------------------------------------------------------------------
c
c     ON FIRST CALL INITIALIZE POWERS OF 10
c
c-----------------------------------------------------------------------
      DATA IPASS/0/
      IF(IPASS.NE.0) GO TO 50
      IPASS=1
c-----INTEGER*8 for long integers
      INMAN4  = 10000
      INMAN5  = 10*INMAN4
      INMAN6  = 10*INMAN5
      INMAN7  = 10*INMAN6
      INMAN8  = 10*INMAN7
      INMAN9  = 10*INMAN8
      TENS(0)=1.0D+00
C-----12/18/2012 - EXTENDED FOR 3 DIGIT EXPONENT
C-----11/22/2013 - Restricted to 2 Digit Exponent
      DO 10 I=1,99
      TENS( I)=TENS(I-1)*10.0D+00
      TENS(-I)=TENS(1-I)/10.0D+00
   10 ROUNDER(I)  = 5.001D-05
      DO 20 I=-99,-10
   20 ROUNDER(I)  = 5.001D-05
      DO 30 I=-9,-4
   30 ROUNDER(I)  = 5.001D-06
      ROUNDER(-3) = 5.001D-07
      ROUNDER(-2) = 5.001D-08
      ROUNDER(-1) = 5.001D-09
      ROUNDER( 0) = 5.001D-09
      DO 40 I=1,8
   40 ROUNDER(I)  = 5.001D-09
      ROUNDER(9)  = 5.001D-06
c-----------------------------------------------------------------------
C
C     IMMEDIATELY RETURN 0.00000+00.
C
c-----------------------------------------------------------------------
C-----02/14/04 - ADDED, JUST IN CASE
   50 IF(DABS(ZIN).le.0.0D+0) GO TO 60
      IF(DABS(ZIN).lt.1.0D-99) GO TO 60    ! Only 2 digit exponents
      IF(DABS(ZIN).gt.1.0D+99) GO TO 60
c----- ZIN = 0 handled above
      IF(ZIN.lt.0.0d+0) go to 80
      go to 90
c-----Return 0
   60 DO 70 I=1,11
   70 FIELD(I)=ZEROH(I)
      RETURN
c-----------------------------------------------------------------------
C
C     DEFINE SIGN OF MANTISSA AND ABSOLUTE MANTISSA
C
c-----------------------------------------------------------------------
C-----NEGATIVE.
   80 FIELD(1)='-'
      Z=-ZIN
      GO TO 100
C-----POSITIVE.
   90 FIELD(1)=' '
      Z=ZIN
c-----------------------------------------------------------------------
c
c     DEFINE EXPONENT AND NORMALIZED MANTISSA
c
c-----------------------------------------------------------------------
  100 IEXP=DLOG10(Z)
      IF(Z.LT.1.0D+00) IEXP = IEXP - 1
c-----11/22/2013 - Decide here on F or E Output
c-----11/26/2013 - Restrict to 2 digit exponent - may change by 1 or 2
      if(IABS(IEXP).gt.97) go to 60
      if(ZIN.lt.0.0D+0) then
      ZN=Z*TENS(-IEXP) + ROUNDER(IEXP)       ! Standard
      else
      if(Z.LE.ZLOW.OR.Z.GE.ZHIGH) then       ! F or E Format?
      ZN=Z*TENS(-IEXP) + TENTH*ROUNDER(IEXP) ! Extra Digit
      else
      ZN=Z*TENS(-IEXP) + ROUNDER(IEXP)       ! Standard
      endif
      endif
      IF(ZN.eq.1.0D+00) go to 120            ! Test rounding underflow
      IF(ZN.gt.1.0D+00) go to 110            ! Test rounding underflow
      IEXP=IEXP-1         ! MUST be < 1
      GO TO 120
  110 IF(ZN.lt.10.0D+00) go to 120           ! Test rounding overflow
      IEXP=IEXP+1         ! MUST be >= 10
      ZN=ZN/10.0D+00
  120 Z = ZN*TENS(IEXP)
c-----------------------------------------------------------------------
C
C     SELECT F OR E FORMAT
C
c-----------------------------------------------------------------------
      IF(Z.LE.ZLOW.OR.Z.GE.ZHIGH) GO TO 150
c-----------------------------------------------------------------------
C
C     F FORMAT
C
C     12345678901
C      X.XXXXXXXX = 9 DIGITS
C      .001234567
C      123456789.
C
c-----------------------------------------------------------------------
C-----DEFINE 6 TO 9 DIGIT MANTISSA WITH ROUNDING
      IPOWER=8-IEXP
      IF(IEXP.LT.0) IPOWER=8
      INMANT=Z*TENS(IPOWER)
C-----CHECK FOR OVERFLOW DUE TO ROUNDING
      if(INMANT.lt.INMAN9) go to 130
      INMANT=INMAN8
      IEXP=IEXP+1
C-----DECIMAL POINT.
  130 IDOT=3+IEXP
      IF(IDOT.LE.2) THEN
C----- IF < 1, MOVE DECIMAL POINT TO COLUMN 2 AND ADD A DIGIT
      IDOT=2
      INMANT=Z*10.0D+00*TENS(IPOWER)
      ENDIF
      FIELD(IDOT)='.'
C-----MANTISSA - LAST DIGIT TO FIRST.
      II=11
      DO 140 I=2,11
      IF(II.EQ.IDOT) GO TO 140
      I2=INMANT/10
      I3=INMANT-10*I2
      FIELD(II)=DIGITS(I3)
      INMANT=I2
  140 II=II-1
      RETURN
c-----------------------------------------------------------------------
C
C     E FORMAT
C
C     12345678901
C      X.XXXXE+NN = 5 DIGITS
C      X.XXXXXE+N = 6 DIGITS
C
C     11/22/2013 - If not negative, use first column
C     12345678901
C     X.XXXXXE+NN = 6 DIGITS
C     X.XXXXXXE+N = 7 DIGITS
c
c-----------------------------------------------------------------------
C-----Negative?
  150 IF(ZIN.lt.0.0d+0) go to 170
c
c     POsitive. Use first column - Decimal point is always in column 2
c
      FIELD(2)='.'
      KDOT    = 2
      ISTART  = 1
      IF(IABS(IEXP).GE.10) GO TO 160
      ID=8                               ! 1 Digit exponent
      INMANT=(1.0D+06)*ZN
      IF(INMANT.lt.INMAN7) go to 190
      INMANT=INMAN6
      IEXP=IEXP+1
      IF(IABS(IEXP).LT.10) GO TO 190
  160 ID=7                               ! 2 Digit exponent
      INMANT=(1.0D+05)*ZN
C-----CHECK FOR OVERFLOW DUE TO ROUNDING
      IF(INMANT.lt.INMAN6) go to 190
      INMANT=INMAN5
      IEXP=IEXP+1
c
c     Negative Number - Cannot use first column
c
C-----DECIMAL POINT IS ALWAYS IN COLUMN 3
  170 FIELD(3)='.'
      KDOT    = 3
      ISTART  = 2
      IF(IABS(IEXP).GE.10) GO TO 180
      ID=8                                 ! 1 Digit Exponent
      INMANT=(1.0D+05)*ZN
      IF(INMANT.lt.INMAN6) go to 190
      INMANT=INMAN5
      IEXP=IEXP+1
      IF(IABS(IEXP).LT.10) GO TO 190
  180 ID=7                                 ! 2 Digit Exponent
      INMANT=(1.0D+04)*ZN
      IF(INMANT.lt.INMAN5) go to 190
      INMANT=INMAN4
      IEXP=IEXP+1
C
C     DEFINE MANTISSA
C
  190 IEXPS=ID+1
      II=ID
      DO 200 I=ISTART,ID
      IF(II.EQ.KDOT) GO TO 200
      I2=INMANT/10
      I3=INMANT-10*I2
      FIELD(II)=DIGITS(I3)
      INMANT=I2
  200 II=II-1
C
C     E
C
      FIELD(IEXPS) = 'E'
      IEXPS = IEXPS + 1
C
C     SIGN OF EXPONENT
C
      IF(IEXP.ge.0) go to 210
      IEXP=-IEXP
      FIELD(IEXPS)='-'
      GO TO 220
  210 FIELD(IEXPS)='+'
C
C     EXPONENT
C
  220 IF(IEXP.lt.10) go to 230
      KEXP=IEXP/10
      FIELD(10)=DIGITS(KEXP)
      IEXP=MOD(IEXP,10)
  230 FIELD(11)=DIGITS(IEXP)
c
c     If using column 1 but mantissa ends in 0, move mantissa right.
c
      if(KDOT.eq.2.and.FIELD(ID).eq.'0') then
      do k=ID-1,1,-1
      FIELD(k+1)=FIELD(k)
      enddo
      FIELD(1) = ' '
      endif
      RETURN
      END
      SUBROUTINE OUT9G(ZIN,FIELD)
C=======================================================================
C
C     PURPOSE
C     =======
C     20915/7/28 - same as OUT9, but column 1 is always '-' or blank.
C                  Used by GROUPIE to simplify listings.
C
C     FORMAT NUMBER FOR OUTPUT TO INCLUDE AS MANY DIGITS OF
C     ACCURACY AS POSSIBLE.
C     12/18/2012 - EXTENDED FOR 3 DIGIT EXPONENT
C                  No test for 4 or more digit exponent
C     10/25/2014 - Changed from D to E exponential form to improve
C                  compatibility between computer languages
C
C     040923 - CHANGED ZLOW FROM 1.0D-4 TO 1.0D-3
C              NEAR 1.0D-3 PRECISION GOES FROM 999,999 TO 1,000,000
C              FOR SMOOTHEST TRANSITION FROM 6 TO 7 DIGITS
C
C     ARGUMENTS
C     =========
C     Z        = FLOATING POINT NUMBER OF BE OUTPUT (INPUT)
C     FIELD    = 11A1 CHARACTERS TO OUTPUT          (OUTPUT)
C
C     METHOD
C     ======
C     COLUMNS            12345678901     ACCURACY
C     -------------------------------------------
C     0 TO 10^-9          1.2345E-12     5 DIGITS
C     10^-9 TO 10^-3      1.23456E-8     6 DIGITS
C     10^-3 TO 10^-2      .001234567     7 DIGITS
C     10^-2 TO 10^-1      .012345678     8 DIGITS
C     10^-1 TO 1          .123456789     9 DIGITS
C     1 TO 10^9           12345.6789     9 DIGITS
C     10^9 TO 10^10       1.23456E+9     6 DIGITS
C     10^10 >             1.2345E+12     5 DIGITS
C
C     OUTPUT WILL BE IN 11 COLUMN FORMAT
C
C     WARNING - THIS IS NOT A GENERAL ROUNDING ROUTINE WHICH WILL WORK
C               FOR ROUNDING TO ANY NUMBER OF DIGITS - IT WILL ONLY
C               WORK PROPERLY FOR THE RANGES INDICATED ABOVE, FOR
C               11 COLUMN OUTPUT.
C
C=======================================================================
      implicit real*8 (a-h,o-z)
      implicit integer*4 (i-n)
      save
c-----INTEGER*8 for long integers
      integer*8 INMANT,INMAN9,INMAN8,INMAN7,INMAN6,INMAN5,INMAN4
      CHARACTER*1 FIELD,DIGITS,ZEROH
C-----12/18/2012 - EXTENDED FOR 3 DIGIT EXPONENT
      DIMENSION DIGITS(0:9),FIELD(11),ZEROH(11),
     1 TENS(-99:99),ROUNDER(-99:99)
      DATA DIGITS/
     1 '0','1','2','3','4','5','6','7','8','9'/
C-----RETURN FOR = 0
      DATA ZEROH/
     1 ' ','0','.','0',' ',' ',' ',' ',' ',' ',' '/
C-----LOWER TRANSITION POINT FROM 7 TO 9 DIGIT OUTPUT
      DATA ZLOW/1.0D-03/
C-----UPPER TRANSITION POINT FROM 9 TO 7 DIGIT OUTPUT
      DATA ZHIGH/1.0D+09/
      DATA TENTH/1.0D-01/
c-----------------------------------------------------------------------
c
c     ON FIRST CALL INITIALIZE POWERS OF 10
c
c-----------------------------------------------------------------------
      DATA IPASS/0/
      IF(IPASS.NE.0) GO TO 50
      IPASS=1
c-----INTEGER*8 for long integers
      INMAN4  = 10000
      INMAN5  = 10*INMAN4
      INMAN6  = 10*INMAN5
      INMAN7  = 10*INMAN6
      INMAN8  = 10*INMAN7
      INMAN9  = 10*INMAN8
      TENS(0)=1.0D+00
C-----12/18/2012 - EXTENDED FOR 3 DIGIT EXPONENT
C-----11/22/2013 - Restricted to 2 Digit Exponent
      DO 10 I=1,99
      TENS( I)=TENS(I-1)*10.0D+00
      TENS(-I)=TENS(1-I)/10.0D+00
   10 ROUNDER(I)  = 5.001D-05
      DO 20 I=-99,-10
   20 ROUNDER(I)  = 5.001D-05
      DO 30 I=-9,-4
   30 ROUNDER(I)  = 5.001D-06
      ROUNDER(-3) = 5.001D-07
      ROUNDER(-2) = 5.001D-08
      ROUNDER(-1) = 5.001D-09
      ROUNDER( 0) = 5.001D-09
      DO 40 I=1,8
   40 ROUNDER(I)  = 5.001D-09
      ROUNDER(9)  = 5.001D-06
c-----------------------------------------------------------------------
C
C     IMMEDIATELY RETURN 0.00000+00.
C
c-----------------------------------------------------------------------
C-----02/14/04 - ADDED, JUST IN CASE
   50 IF(DABS(ZIN).le.0.0D+0) GO TO 60
      IF(DABS(ZIN).lt.1.0D-99) GO TO 60    ! Only 2 digit exponents
      IF(DABS(ZIN).gt.1.0D+99) GO TO 60
c----- ZIN = 0 handled above
      IF(ZIN.lt.0.0d+0) go to 80
      go to 90
c-----Return 0
   60 DO 70 I=1,11
   70 FIELD(I)=ZEROH(I)
      RETURN
c-----------------------------------------------------------------------
C
C     DEFINE SIGN OF MANTISSA AND ABSOLUTE MANTISSA
C
c-----------------------------------------------------------------------
C-----NEGATIVE.
   80 FIELD(1)='-'
      Z=-ZIN
      GO TO 100
C-----POSITIVE.
   90 FIELD(1)=' '
      Z=ZIN
c-----------------------------------------------------------------------
c
c     DEFINE EXPONENT AND NORMALIZED MANTISSA
c
c-----------------------------------------------------------------------
  100 IEXP=DLOG10(Z)
      IF(Z.LT.1.0D+00) IEXP = IEXP - 1
c-----11/22/2013 - Decide here on F or E Output
c-----11/26/2013 - Restrict to 2 digit exponent - may change by 1 or 2
      if(IABS(IEXP).gt.97) go to 60
      ZN=Z*TENS(-IEXP) + ROUNDER(IEXP)       ! Standard
      IF(ZN.eq.1.0D+00) go to 120            ! Test rounding underflow
      IF(ZN.gt.1.0D+00) go to 110            ! Test rounding underflow
      IEXP=IEXP-1         ! MUST be < 1
      GO TO 120
  110 IF(ZN.lt.10.0D+00) go to 120           ! Test rounding overflow
      IEXP=IEXP+1         ! MUST be >= 10
      ZN=ZN/10.0D+00
  120 Z = ZN*TENS(IEXP)
c-----------------------------------------------------------------------
C
C     SELECT F OR E FORMAT
C
c-----------------------------------------------------------------------
      IF(Z.LE.ZLOW.OR.Z.GE.ZHIGH) GO TO 150
c-----------------------------------------------------------------------
C
C     F FORMAT
C
C     12345678901
C      X.XXXXXXXX = 9 DIGITS
C      .001234567
C      123456789.
C
c-----------------------------------------------------------------------
C-----DEFINE 6 TO 9 DIGIT MANTISSA WITH ROUNDING
      IPOWER=8-IEXP
      IF(IEXP.LT.0) IPOWER=8
      INMANT=Z*TENS(IPOWER)
C-----CHECK FOR OVERFLOW DUE TO ROUNDING
      if(INMANT.lt.INMAN9) go to 130
      INMANT=INMAN8
      IEXP=IEXP+1
C-----DECIMAL POINT.
  130 IDOT=3+IEXP
      IF(IDOT.LE.2) THEN
C----- IF < 1, MOVE DECIMAL POINT TO COLUMN 2 AND ADD A DIGIT
      IDOT=2
      INMANT=Z*10.0D+00*TENS(IPOWER)
      ENDIF
      FIELD(IDOT)='.'
C-----MANTISSA - LAST DIGIT TO FIRST.
      II=11
      DO 140 I=2,11
      IF(II.EQ.IDOT) GO TO 140
      I2=INMANT/10
      I3=INMANT-10*I2
      FIELD(II)=DIGITS(I3)
      INMANT=I2
  140 II=II-1
      RETURN
c-----------------------------------------------------------------------
C
C     E FORMAT
C
C     12345678901
C      X.XXXXE+NN = 5 DIGITS
C      X.XXXXXE+N = 6 DIGITS
C
C     11/22/2013 - If not negative, use first column
C     12345678901
C     X.XXXXXE+NN = 6 DIGITS
C     X.XXXXXXE+N = 7 DIGITS
c
c-----------------------------------------------------------------------
c
c     Do not cannot use first column
c
C-----DECIMAL POINT IS ALWAYS IN COLUMN 3
  150 FIELD(3)='.'
      KDOT    = 3
      ISTART  = 2
      IF(IABS(IEXP).GE.10) GO TO 160
      ID=8                                 ! 1 Digit Exponent
      INMANT=(1.0D+05)*ZN
      IF(INMANT.lt.INMAN6) go to 170
      INMANT=INMAN5
      IEXP=IEXP+1
      IF(IABS(IEXP).LT.10) GO TO 170
  160 ID=7                                 ! 2 Digit Exponent
      INMANT=(1.0D+04)*ZN
      IF(INMANT.lt.INMAN5) go to 170
      INMANT=INMAN4
      IEXP=IEXP+1
C
C     DEFINE MANTISSA
C
  170 IEXPS=ID+1
      II=ID
      DO 180 I=ISTART,ID
      IF(II.EQ.KDOT) GO TO 180
      I2=INMANT/10
      I3=INMANT-10*I2
      FIELD(II)=DIGITS(I3)
      INMANT=I2
  180 II=II-1
C
C     E
C
      FIELD(IEXPS) = 'E'
      IEXPS = IEXPS + 1
C
C     SIGN OF EXPONENT
C
      IF(IEXP.ge.0) go to 190
      IEXP=-IEXP
      FIELD(IEXPS)='-'
      GO TO 200
  190 FIELD(IEXPS)='+'
C
C     EXPONENT
C
  200 IF(IEXP.lt.10) go to 210
      KEXP=IEXP/10
      FIELD(10)=DIGITS(KEXP)
      IEXP=MOD(IEXP,10)
  210 FIELD(11)=DIGITS(IEXP)
      RETURN
      END
      FUNCTION NXTSEQ(NNSEQ)
C=======================================================================
C
C     DEFINE NEXT SEQUENCE NUMBER FOR ENDF/B OUTPUT. ALLOW FOR
C     MORE THAN 100000 LINES PER EVALUATION BY RESETTING NUMBER
C     TO 1 EVERY TIME 100000 IS REACHED.
C
C=======================================================================
      INCLUDE 'implicit.h'
      NN=NNSEQ+1
      IF(NN.EQ.100000) NN=1
      NXTSEQ=NN
      RETURN
      END
